package login

import (
	"time"

	"zombiezen.com/go/sqlite"
	"zombiezen.com/go/sqlite/sqlitex"
)

// Represents an account on the login server.
type Account struct {
	ID                int64     `db:"id"`
	Name              string    `db:"name"`
	Passwd            string    `db:"passwd"`
	IPAddress         string    `db:"ip_address"`
	EmailAddress      string    `db:"email_address"`
	CreatedDate       int32     `db:"created_date"`
	Key1              string    `db:"key1"`
	LastUpdate        time.Time `db:"last_update"`
	HackCount         int8      `db:"hack_count"`
	LastClientVersion int16     `db:"last_client_version"`
	AccountEnabled    bool      `db:"account_enabled"`
}

// Creates the account table if it doesn't exist.
func CreateAccountTable(conn *sqlite.Conn) error {
	return sqlitex.ExecScript(conn, `
		CREATE TABLE IF NOT EXISTS account (
			id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
			name TEXT NOT NULL UNIQUE DEFAULT '',
			passwd TEXT NOT NULL DEFAULT '',
			ip_address TEXT NOT NULL DEFAULT '0',
			email_address TEXT NOT NULL DEFAULT 'Unknown',
			created_date INTEGER NOT NULL DEFAULT 0,
			key1 TEXT NOT NULL DEFAULT '0',
			last_update TEXT NOT NULL DEFAULT CURRENT_TIMESTAMP,
			hack_count INTEGER NOT NULL DEFAULT 0,
			last_client_version INTEGER NOT NULL DEFAULT 0,
			account_enabled INTEGER NOT NULL DEFAULT 1
		);
	`)
}
