package login

import (
	"time"

	"zombiezen.com/go/sqlite"
	"zombiezen.com/go/sqlite/sqlitex"
)

// Represents a login equipment item.
type LoginEquipment struct {
	ID                int64     `db:"id"`
	LoginCharactersID int32     `db:"login_characters_id"`
	EquipType         int16     `db:"equip_type"`
	Red               int8      `db:"red"`
	Green             int8      `db:"green"`
	Blue              int8      `db:"blue"`
	HighlightRed      int8      `db:"highlight_red"`
	HighlightGreen    int8      `db:"highlight_green"`
	HighlightBlue     int8      `db:"highlight_blue"`
	Slot              int32     `db:"slot"`
	LastUpdated       time.Time `db:"last_updated"`
}

// Creates a new login equipment table in the database.
func CreateLoginEquipmentTable(conn *sqlite.Conn) error {
	return sqlitex.ExecScript(conn, `
		CREATE TABLE IF NOT EXISTS login_equipment (
			id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
			login_characters_id INTEGER NOT NULL DEFAULT 0,
			equip_type INTEGER NOT NULL DEFAULT 0,
			red INTEGER NOT NULL DEFAULT 255,
			green INTEGER NOT NULL DEFAULT 255,
			blue INTEGER NOT NULL DEFAULT 255,
			highlight_red INTEGER NOT NULL DEFAULT 255,
			highlight_green INTEGER NOT NULL DEFAULT 255,
			highlight_blue INTEGER NOT NULL DEFAULT 255,
			slot INTEGER NOT NULL DEFAULT 0,
			last_updated TEXT NOT NULL DEFAULT CURRENT_TIMESTAMP,
			UNIQUE(login_characters_id, slot)
		);
	`)
}
